exceptiontools.MissingNoteHeadError
===================================

.. inheritance-diagram:: abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingNoteHeadError.MissingNoteHeadError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
